#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-cors
version:              0.2.7
visibility:           public
id:                   wai-cors-0.2.7-34JZ9xMhHvxGoMiOL4Qh9C
key:                  wai-cors-0.2.7-34JZ9xMhHvxGoMiOL4Qh9C
license:              MIT
copyright:
    (c) 2015-2019 Lars Kuhtz <lakuhtz@gmail.com>,
    (c) 2014 AlephCloud Systems, Inc.

maintainer:           Lars Kuhtz <lakuhtz@gmail.com>
author:               Lars Kuhtz <lakuhtz@gmail.com>
homepage:             https://github.com/larskuhtz/wai-cors
synopsis:             CORS for WAI
description:
    This package provides an implemenation of
    Cross-Origin resource sharing (CORS) for
    <http://hackage.haskell.org/package/wai Wai>
    that aims to be compliant with <http://www.w3.org/TR/cors>.

category:             HTTP, Network, Web, Wai
abi:                  1f1e280be5ebba55b2b44c91abb76426
exposed:              True
exposed-modules:      Network.Wai.Middleware.Cors
import-dirs:          /usr/lib/ghc-9.6.6/site-local/wai-cors-0.2.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/wai-cors-0.2.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/wai-cors-0.2.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-cors
hs-libraries:         HSwai-cors-0.2.7-34JZ9xMhHvxGoMiOL4Qh9C
depends:
    attoparsec-0.14.4-Jn9OdnAKkVz1hO2dwh0zwz base-4.18.2.1
    base-unicode-symbols-0.2.4.2-LX7whyw4bmGCqzVQbQIjtq
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-2Yyf9IxnGFQLPP0jk4pg3Q
    http-types-0.12.4-57DQrkzau5HINFiGCpRQOB mtl-2.3.1
    transformers-0.6.1.0 wai-3.2.4-1UZqbeDwj2g6CvYOTQFqve

haddock-interfaces:   /usr/share/doc/haskell-wai-cors/html/wai-cors.haddock
haddock-html:         /usr/share/doc/haskell-wai-cors/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

